*********************************************************************************
* "Tenurial security and agricultural investment: Evidence from Vietnam"		*
* Marc Bellemare, Kenn Chua, Julieth Santamaria, Khoa Vu						*
* Replication Files	- 1_Cleaning_hhpanel.do										*	
*********************************************************************************

*===============================================================================*
*1. Create temporary files with harmonized variable names per module-year 		*
*===============================================================================*


forvalues yr = 2008(2)2016 {
	local y "`=`yr'-2000'"
	// Set up locals to call variables in each module
	if `yr' == 2008  { // beginning chars of vars from Q2-Q3A modules in 2008
		local mod1	"6" 
		local mod2	"9"
		local mod3	"10"
		local mod4	"11"
		local mod5	"12"
		local mod6	"13"
		local mod7	"15"
		local mod8	"17"
	}
		
	if `yr' > 2008 { // beginning chars of vars from Q2-Q2E modules in 2010-2016
		local mod1	"5" 
		local mod2	"8"
		local mod3	"9"
		local mod4	"10"
		local mod5	"11"
		local mod6	"12"
	}
		
	if `yr' == 2010 { // beginning chars of vars from Q2F-Q3A modules in 2010
		local mod7	"14"
		local mod8	"16"
	}
		
	if `yr' == 2012 { // beginning chars of vars from Q2F-Q3A modules in 2012
		local mod7	"13"
		local mod8	"14"
	}
		
	if `yr' >= 2014 { // beginning chars of vars from Q2F-Q3A modules in 2014-2016
		local mod7	"13"
		local mod8	"15"
	}
	
	foreach mod in Q2 Q2A Q2B Q2C Q2D Q2E /*Q2F*/ Q3A {
		if `yr' == 2008 {
			use "${RAWDATA}Household_clean/`yr'_new/`mod'_New.dta", clear
		}
		
		if `yr' > 2008 { 
			use "${RAWDATA}Household_clean/`yr'_new/`mod'_New_`y'.dta", clear
		
		}
		
		
		// rename variables 
		if "`mod'"=="Q2" {
			// rename default so that they all begin with p`mod1'q*
			local mod1x "`=`mod1'+1'" 
			local mod1y "`=`mod1'+2'"
			
			rename p`mod1x'q* p`mod1'q*
			rename p`mod1y'q* p`mod1'q*
			
			// rename revised defaults to new varnames
			rename p`mod1'ma_ 	plotcode 
			rename p`mod1'q1_ 	m2_q1
			rename p`mod1'q2_ 	m2_q2
			rename p`mod1'q4_ 	m2_q4
			rename p`mod1'q5_ 	m2_q5
			rename p`mod1'q6_ 	m2_q6
			rename p`mod1'q7_ 	m2_q7
			
			// inconsistent default variable labels across years
			* Area of plot and difference?
			if `yr' == 2008 {
				rename p`mod1'q3_ m2_q3_a
			}
			else {
				rename p`mod1'q3a_ m2_q3_a
				rename p`mod1'q3b_ m2_q3_b
			}
			
			* Slope; soil and water conservation infra on plot; etc.
			if `yr' <=2012 {
				rename p`mod1'q9_ 	m2_q8
				rename p`mod1'q16a_ m2_q16_a
				rename p`mod1'q16b_	m2_q16_b
				rename p`mod1'q17_ 	m2_q17_a
				rename p`mod1'q18_ 	m2_q17_b
				rename p`mod1'q19_ 	m2_q18
				rename p`mod1'q20_ 	m2_q19_a
				rename p`mod1'q21_ 	m2_q19_b
			}
			if `yr' >=2014 {
				rename p`mod1'q8_ 	m2_q8
				rename p`mod1'q15a_ m2_q16_a
				rename p`mod1'q15b_	m2_q16_b
				rename p`mod1'q16_ 	m2_q17_a
				rename p`mod1'q17_ 	m2_q17_b
				rename p`mod1'q18_ 	m2_q18
				rename p`mod1'q19_ 	m2_q19_a
				rename p`mod1'q20_ 	m2_q19_b
			}
		} 
		if "`mod'"=="Q2A" {
			// rename revised defaults to new varnames
			rename p`mod2'ma_ 	plotcode 
			rename p`mod2'q1_ 	m2a_q1
			rename p`mod2'q3a_ 	m2a_q3_a
			rename p`mod2'q3b_ 	m2a_q3_b
			rename p`mod2'q4_ 	m2a_q4
			
			// inconsistent default variable labels across years
			* Do you have a red book? Why not?
			if `yr' == 2008 {
				rename p`mod2'q2_ m2_q2_a
			}
			else {
				rename p`mod2'q2a_ m2_q2_a
				rename p`mod2'q2b_ m2_q2_b
			}
			
			// gen plotOwnship variable (Q2A = owned and operated) 
			gen plotOwnship = 1	
		}
		if "`mod'"=="Q2B" {
			// rename revised defaults to new varnames
			rename p`mod3'ma_ 	plotcode 
			rename p`mod3'q1_ 	m2b_q1
			rename p`mod3'q2_ 	m2b_q2
			rename p`mod3'q3_ 	m2b_q3
			rename p`mod3'q4_ 	m2b_q4
			rename p`mod3'q5_ 	m2b_q5
			
			// gen plotOwnship variable (Q2B = borrowed)
			gen plotOwnship = 2	
		}
		if "`mod'"=="Q2C" {
			// rename revised defaults to new varnames
			rename p`mod4'ma_ 	plotcode 
			rename p`mod4'q1_ 	m2c_q1	
			rename p`mod4'q3a_ 	m2c_q3_a
			rename p`mod4'q3b_ 	m2c_q3_b
			rename p`mod4'q4_ 	m2c_q4
			
			
			// inconsistent default variable labels across years
			* Do you have a red book for this land? Why not?
			if `yr' == 2008 {
				rename p`mod4'q2_ m2c_q2_a
			}
			else {
				rename p`mod4'q2a_ m2c_q2_a
				rename p`mod4'q2b_ m2c_q2_b
			}
			
			* When did you start to lend out plot?
			if `yr' <= 2010 {
				rename p`mod4'q12_ 	m2c_q12
			}
			else {
				rename p`mod4'q11_ 	m2c_q12
			}
			
			// gen plotOwnship variable (Q2C = rented out)
			gen plotOwnship = 3	
		}
		if "`mod'"=="Q2D" {
			// rename revised defaults to new varnames
			rename p`mod5'ma_ 	plotcode 
			rename p`mod5'q1_ 	m2d_q1
			rename p`mod5'q3a_ 	m2d_q3_a
			rename p`mod5'q3b_ 	m2d_q3_b
			rename p`mod5'q4_ 	m2d_q4
			rename p`mod5'q5_ 	m2d_q5
			rename p`mod5'q6_ 	m2d_q6
			rename p`mod5'q7_ 	m2d_q7
			rename p`mod5'q8_ 	m2d_q8
			rename p`mod5'q9_ 	m2d_q9
			rename p`mod5'q10_ 	m2d_q10
			
			// inconsistent default variable labels across years
			* Do you have a red book for this land? Why not?
			if `yr' == 2008 {
				rename p`mod5'q2_ m2d_q2_a
			}
			else {
				rename p`mod5'q2a_ m2d_q2_a
				rename p`mod5'q2b_ m2d_q2_b
			}
			
			// gen plotOwnship variable (Q2D = sold or taken away)
			gen plotOwnship = 4	
		}
		if "`mod'"=="Q2E" {
			// rename default so that they all begin with p`mod1'q*
			local mod6x "`=`mod6'+1'" 
			
			rename p`mod6x'q* p`mod6'q*
			
			// rename revised defaults to new varnames
			rename p`mod6'ma_ 	plotcode 
			rename p`mod6'q1_	m2e_q1
			rename p`mod6'q2a_ 	m2e_q2_a
			rename p`mod6'q2b_ 	m2e_q2_b
			rename p`mod6'q5_ 	m2e_q5
			
		
			* Permanent structure investments on plot?
			rename p`mod6'q8_	m2e_q8
			
			* Tree planted and bushes?
			if `yr'== 2010 {
				gen p`mod6'q11_ = 1 if p`mod6'q12_>0 & !missing(p`mod6'q12_)
				replace p`mod6'q11_ = 2 if p`mod6'q12_==0
			}
			rename p`mod6'q11_	m2e_q11
		}
		
		if "`mod'"=="Q3A" {
			// rename default to new varnames
			*2008-2010 all
			if `yr'<=2010 {
				rename p`mod8'ma1_	plotcode
				rename p`mod8'q1_ 	m3a_q1_1
				rename p`mod8'q2_ 	m3a_q2_1
				rename p`mod8'q3_ 	m3a_q3a_1
				rename p`mod8'q4_ 	m3a_q3b_1
				rename p`mod8'q5_ 	m3a_q4_1
				rename p`mod8'q6_ 	m3a_q1_2
				rename p`mod8'q7_ 	m3a_q2_2
				rename p`mod8'q8_ 	m3a_q3a_2
				rename p`mod8'q9_ 	m3a_q3b_2
				rename p`mod8'q10_ 	m3a_q1_3
				rename p`mod8'q11_ 	m3a_q2_3
				rename p`mod8'q12_ 	m3a_q3a_3
				rename p`mod8'q13_ 	m3a_q3b_3
			}
			
			*2012-2016 all 
			if `yr'>=2012 {
				rename p`mod8'ma1_	plotcode
				rename p`mod8'q1_ 	m3a_q1_1
				rename p`mod8'q2_ 	m3a_q2_1
				rename p`mod8'q3a_ 	m3a_q3a_1
				rename p`mod8'q3b_ 	m3a_q3b_1
				rename p`mod8'q4_ 	m3a_q4_1
				rename p`mod8'q5_ 	m3a_q1_2
				rename p`mod8'q6_ 	m3a_q2_2
				rename p`mod8'q7a_ 	m3a_q3a_2
				rename p`mod8'q7b_ 	m3a_q3b_2
				rename p`mod8'q8_ 	m3a_q1_3
				rename p`mod8'q9_ 	m3a_q2_3
				rename p`mod8'q10a_ m3a_q3a_3
				rename p`mod8'q10b_ m3a_q3b_3
			}
		
		}
		
		// drop duplicate plots
		duplicates drop tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr' plotcode, force
		
		// save 
		keep tinh* quan* xa* plot* m* panel* /*hhID**/ 
		save "${INTDATA}Temp/temp_`yr'_`mod'.dta", replace
	}
}



*===============================================================================*
* 2. Merge modules (Q2, Q2A, Q2B, Q2C, Q2D, Q2E) from same year. 				*
*===============================================================================*


forvalues yr = 2008(2)2016 {
	// merge Q2 with Q2A, Q2B, Q2C, Q2D, Q2E
	use "${INTDATA}Temp/temp_`yr'_Q2.dta", clear
	local mergeplotID tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr' plotcode 
	
	foreach mod in Q2A Q2B Q2C Q2D Q2E {
		merge 1:1 `mergeplotID' using "${INTDATA}Temp/temp_`yr'_`mod'.dta", update 
		drop _merge 
	}
	
	// Count plot use unknown
	tab plotOwnship, missing
	*I do not know plotOwnship of these but I do know if m2_q7 (type of plot)
	
	// Save appended
	gen year = `=`yr'-2000'
	save "${INTDATA}Temp/temp_`yr'_2ABCDE.dta", replace 
	
}


*===============================================================================*
* 3.  HH Aggregates of Plot Data; Merge in Additional Variables at the HH Level *
*===============================================================================*

forvalues yr = 2008(2)2016 {
	use "${INTDATA}Temp/temp_`yr'_2ABCDE.dta", clear
	local hhID tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr' 
	
	*3a) Generate new variables 
	*Number of non-residential plots by ownership (owned, borrowed, rented out, sold)
	local nonresidential "& m2_q7!=7 & m2_q7!=8"
	bys `hhID' : egen nrplot_own = total(plotOwnship==1 `nonresidential' ) // compare with VARHS data: nrplotown
	bys `hhID' : egen nrplot_borr = total(plotOwnship==2 `nonresidential')
	bys `hhID' : egen nrplot_rent = total(plotOwnship==3 `nonresidential')
	bys `hhID' : egen nrplot_sold = total(plotOwnship==4 `nonresidential')
	bys `hhID' : egen nrplot_all = total(plotOwnship>0 & plotOwnship!=4 `nonresidential') // all not sold and non-residential
	bys `hhID' : egen nrplot_force = total(plotOwnship==4 & m2d_q6==4 & m2d_q8==8 `nonresidential') // number of non-residential plots taken by state
	
	*Number of annual or perennial (i.e. agri) plots owned, borrowed, rented out, sold
	bys `hhID' : egen nrplot_ann_own = total(m2_q7==1 & plotOwnship==1)
	bys `hhID' : egen nrplot_per_own = total(m2_q7==2 & plotOwnship==1)
	bys `hhID' : egen nrplot_agr_own = total((m2_q7==1 | m2_q7==2) & plotOwnship==1)
	
	bys `hhID' : egen nrplot_ann_borr = total(m2_q7==1 & plotOwnship==2)
	bys `hhID' : egen nrplot_per_borr = total(m2_q7==2 & plotOwnship==2)
	
	bys `hhID' : egen nrplot_ann_rent = total(m2_q7==1 & plotOwnship==3)
	bys `hhID' : egen nrplot_per_rent = total(m2_q7==2 & plotOwnship==3)
	
	bys `hhID' : egen nrplot_ann_sold = total(m2_q7==1 & plotOwnship==4)
	bys `hhID' : egen nrplot_per_sold = total(m2_q7==2 & plotOwnship==4)
	
	bys `hhID' : egen nrplot_ann_force = total(m2_q7==1 & plotOwnship==4 &  m2d_q6==4 & m2d_q8==8) // number of annual plots taken by state
	bys `hhID' : egen nrplot_per_force = total(m2_q7==2 & plotOwnship==4 &  m2d_q6==4 & m2d_q8==8) // number of perennial plots taken by state
	
	*Total area of non-residential plots by ownership (owned, borrowed, rented out, sold)
	bys `hhID' : egen plotArea_own = total(m2_q3_a) if plotOwnship==1 `nonresidential' // compare with HH data: totareaown
	bys `hhID' : egen plotArea_borr = total(m2_q3_a) if plotOwnship==2 `nonresidential'
	bys `hhID' : egen plotArea_rent = total(m2_q3_a) if plotOwnship==3 `nonresidential'
	bys `hhID' : egen plotArea_sold = total(m2_q3_a) if plotOwnship==4 `nonresidential'
	bys `hhID' : egen plotArea_all = total(m2_q3_a) if plotOwnship!=4 `nonresidential' // all not sold and non-residential
	bys `hhID' : egen plotArea_force = total(m2_q3_a) if plotOwnship==4 & m2d_q6==4 & m2d_q8==8 `nonresidential' // all non-residential land take by force by state
	
	*Total area of annual or perennial (i.e. agri) plots owned, borrowed, rented out, sold
	bys `hhID' : egen plotArea_ann_own = total(m2_q3_a) if m2_q7==1 & plotOwnship==1
	bys `hhID' : egen plotArea_per_own = total(m2_q3_a) if m2_q7==2 & plotOwnship==1
	bys `hhID' : egen plotArea_agr_own = total(m2_q3_a) if (m2_q7==1 | m2_q7==2) & plotOwnship==1
	
	bys `hhID' : egen plotArea_ann_borr = total(m2_q3_a) if m2_q7==1 & plotOwnship==2
	bys `hhID' : egen plotArea_per_borr = total(m2_q3_a) if m2_q7==2 & plotOwnship==2
	bys `hhID' : egen plotArea_agr_borr = total(m2_q3_a) if (m2_q7==1 | m2_q7==2) & plotOwnship==2
	
	bys `hhID' : egen plotArea_ann_rent = total(m2_q3_a) if m2_q7==1 & plotOwnship==3
	bys `hhID' : egen plotArea_per_rent = total(m2_q3_a) if m2_q7==2 & plotOwnship==3
	bys `hhID' : egen plotArea_agr_rent = total(m2_q3_a) if (m2_q7==1 | m2_q7==2) & plotOwnship==3
	
	bys `hhID' : egen plotArea_ann_sold = total(m2_q3_a) if m2_q7==1 & plotOwnship==4
	bys `hhID' : egen plotArea_per_sold = total(m2_q3_a) if m2_q7==2 & plotOwnship==4
	bys `hhID' : egen plotArea_agr_sold = total(m2_q3_a) if (m2_q7==1 | m2_q7==2) & plotOwnship==4
	
	bys `hhID' : egen plotArea_ann_force = total(m2_q3_a) if m2_q7==1 & plotOwnship==4 & m2d_q6==4 & m2d_q8==8 // area of annual plots taken by state
	bys `hhID' : egen plotArea_per_force = total(m2_q3_a) if m2_q7==2 & plotOwnship==4 & m2d_q6==4 & m2d_q8==8 // area of perennial plots taken by state
	
	*Total area of residential plots 
	bys `hhID' : egen plotArea_resid_own = total(m2_q3_a) if m2_q7==7 & plotOwnship==1 
	
	
	*Indicator of Investment in Annual Plots Owned
	gen p_investSoiWa_ann_o = (m2e_q1==1 & m2_q7==1 & plotOwnship==1) 
	gen p_investInfra_ann_o = (m2e_q8==1 & m2_q7==1 & plotOwnship==1) 
	gen p_investTrees_ann_o = (m2e_q11==1 & m2_q7==1 & plotOwnship==1) 
	gen p_investAquac_ann_o = (m2e_q5==1 & m2_q7==1 & plotOwnship==1) 
	gen p_investAny_ann_o   = (m2_q7==1 & (m2e_q1==1 | m2e_q8==1 | m2e_q11==1 | m2e_q5==1) & plotOwnship==1)
	
	*Indicator of Investment in Perennial Plots Owned
	gen p_investSoiWa_per_o = (m2e_q1==1 & m2_q7==2 & plotOwnship==1) 
	gen p_investInfra_per_o = (m2e_q8==1 & m2_q7==2 & plotOwnship==1) 
	gen p_investTrees_per_o = (m2e_q11==1 & m2_q7==2 & plotOwnship==1) 
	gen p_investAquac_per_o = (m2e_q5==1 & m2_q7==2 & plotOwnship==1) 
	gen p_investAny_per_o   = (m2_q7==2 & (m2e_q1==1 | m2e_q8==1 | m2e_q11==1 | m2e_q5==1) & plotOwnship==1)

	*Area times Indicator of Investment in Annual Plots Owned
	gen w_investSoiWa_ann_o = p_investSoiWa_ann*m2_q3_a if m2_q7==1 & plotOwnship==1
	gen w_investInfra_ann_o = p_investInfra_ann*m2_q3_a if m2_q7==1 & plotOwnship==1
	gen w_investTrees_ann_o = p_investTrees_ann*m2_q3_a if m2_q7==1 & plotOwnship==1
	gen w_investAquac_ann_o = p_investAquac_ann*m2_q3_a if m2_q7==1 & plotOwnship==1
	gen w_investAny_ann_o = p_investAny_ann*m2_q3_a if m2_q7==1 & plotOwnship==1
	
	*Area times Indicator of Investment in Perennials Plots Owned
	gen w_investSoiWa_per_o = p_investSoiWa_per*m2_q3_a if m2_q7==2 & plotOwnship==1
	gen w_investInfra_per_o = p_investInfra_per*m2_q3_a if m2_q7==2 & plotOwnship==1
	gen w_investTrees_per_o = p_investTrees_per*m2_q3_a if m2_q7==2 & plotOwnship==1
	gen w_investAquac_per_o = p_investAquac_per*m2_q3_a if m2_q7==2 & plotOwnship==1
	gen w_investAny_per_o = p_investAny_per*m2_q3_a if m2_q7==2 & plotOwnship==1
	
	*Number of plots owned with crop restrictions
	bys `hhID' : egen nrplot_ann_own_cr = total(m2_q7==1 & plotOwnship==1 & m2_q19_a==1)
	bys `hhID' : egen nrplot_per_own_cr = total(m2_q7==2 & plotOwnship==1 & m2_q19_a==1)
	bys `hhID' : egen nrplot_agr_own_cr = total((m2_q7==1 | m2_q7==2) & plotOwnship==1 & m2_q19_a==1)
	
	*Area of plots owned with crop restrictions 
	bys `hhID' : egen plotArea_ann_own_cr = total(m2_q3_a) if m2_q7==1 & plotOwnship==1 & m2_q19_a==1
	bys `hhID' : egen plotArea_per_own_cr = total(m2_q3_a) if m2_q7==2 & plotOwnship==1 & m2_q19_a==1
	bys `hhID' : egen plotArea_agr_own_cr = total(m2_q3_a) if (m2_q7==1 | m2_q7==2) & plotOwnship==1 & m2_q19_a==1
	
	
	*3b) Collapse into HH-level aggregates 
	collapse (mean) nrplot_* /// total number of plots -> total number of plots
					plotArea_* /// total area of plots -> total area of plots
			 (sum)	p_invest* /// dummy for investment in plot -> total number of plots with investment
					w_invest* /// area if plot has investment -> total area of plots with investment
			 ,by(`hhID' year)	
			
	*3c) Measures of exposure to Vietnam Land Law (2013) [HH Level]
	*Share of annual plots of total area of agri plots owned
	gen sh_ann_area = plotArea_ann_own / plotArea_agr_own // share of annual plots owned over all agricultural plots (ann+per) owned
		replace sh_ann_area = 0 if plotArea_per_own!=. & plotArea_ann_own==. // exclusive perennial holders
	
	*Share of annual plots of total number of plots
	gen sh_ann_nrpl = nrplot_ann_own / nrplot_agr_own // share of annual plots owned over all agricultural plots (ann+per) owned
		*replace sh_ann_area = 0 if nrplot_per_own!=. & nrplot_ann_own==. 
	
	*3d) Measures of investment in any AGRI plot [HH Level]
	*Indicator of whether household invested in any agricultural plot owned
	gen ind_investSoiWa = (p_investSoiWa_ann_o>0 | p_investSoiWa_per_o>0)
	gen ind_investInfra = (p_investInfra_ann_o>0 | p_investInfra_per_o>0)
	gen ind_investTrees = (p_investTrees_ann_o>0 | p_investTrees_per_o>0)
	gen ind_investAquac = (p_investAquac_ann_o>0 | p_investAquac_per_o>0)
	gen ind_investAny   = (p_investAny_ann_o>0   | p_investAny_per_o>0) 
	
	*Share of AGRI plots owned receiving investment (unweighted - based on number of plots)
	gen sh_investSoiWa_nrpl = (p_investSoiWa_ann_o + p_investSoiWa_per_o) / nrplot_agr_own
	gen sh_investInfra_nrpl = (p_investInfra_ann_o + p_investInfra_per_o) / nrplot_agr_own
	gen sh_investTrees_nrpl = (p_investTrees_ann_o + p_investTrees_per_o) / nrplot_agr_own
	gen sh_investAquac_nrpl = (p_investAquac_ann_o + p_investAquac_per_o) / nrplot_agr_own
	gen sh_investAny_nrpl	= (p_investAny_ann_o + p_investAny_per_o) / nrplot_agr_own

	*Share of AGRI plots owned receiving investment (weighted - by area)  
	gen sh_investSoiWa_area = (w_investSoiWa_ann_o+w_investSoiWa_per_o) / plotArea_agr_own
	gen sh_investInfra_area = (w_investInfra_ann_o+w_investInfra_per_o) / plotArea_agr_own
	gen sh_investTrees_area = (w_investTrees_ann_o+w_investTrees_per_o) / plotArea_agr_own
	gen sh_investAquac_area = (w_investAquac_ann_o+w_investAquac_per_o) / plotArea_agr_own
	gen sh_investAny_area	= (w_investAny_ann_o+w_investAny_per_o) / plotArea_agr_own
	
	
	*3e) Merge in additional variables from other modules. 
	local y "`=`yr'-2000'"
	* Knowledge of Land Law
	if `yr' == 2014 | `yr'==2016 {
		merge 1:1 tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr'  using ///
			"${RAWDATA}Household_clean/`yr'_new/Phieu1_New_`y'.dta", ///
			keepusing(p14q1 p14q2 p14q3) 		
		drop if _merge==2 
		drop _merge
		rename (p14q1 p14q2 p14q3) (landlaw_heard landlaw_knowl landlaw_dura)
	}
	
	* Political Connections 
	if `yr' == 2008 {
		local fn Phieu_2_New_OneFile
		local mod "52"
	}
	else if `yr' == 2010 {
		local fn Phieu_2_New_10
		local mod "49"
	}
	else if `yr' == 2012 {
		local fn Phieu_2_New_12
		local mod "51"
	}
	else if `yr' == 2014 {
		local fn Phieu2_New_14
		local mod "54"
	}
	else if `yr' == 2016 {
		local fn Phieu2_New_16
		local mod "57"
	}
	
	merge 1:1 tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr'  using ///
			"${RAWDATA}Household_clean/`yr'_new/`fn'.dta", ///
			keepusing(p`mod'q1 p`mod'q4 p`mod'q7) 
	drop if _merge==2 
	drop _merge 
	
	rename (p`mod'q1 p`mod'q4 p`mod'q7) (polcon_hhmem polcon_relat polcon_frien)
	
	
	*3f) Merge panelid.dta for HH identification
	* Create temporary panelid.dta with no duplicates in terms of IDs
	preserve 
	use "${RAWDATA}Household_clean/panelid.dta", clear
	duplicates drop year tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr', force 
	
	tempfile panelid`yr'
	save `panelid`yr''
	
	/*Note: Duplicates for
	2008 - Have missing 2008 IDs.
	2010 - Have missing 2010 IDs. 
	2012 - Have missing 2012 IDs. 
	2014 - Have missing 2014 IDs.
	2016 - Have missing 2016 IDs.
	*/ 
	
	*3g) Merge with temporary panelid.dta 
	restore 
	local mergeHHID year tinh_`yr' quan_`yr' xa_`yr' ma_h0_`yr'
	
	merge 1:1 `mergeHHID' using `panelid`yr''
	drop if _merge==2
	drop _merge
	
	tempfile plotdata`yr'
	save `plotdata`yr'' 
	di "`plotdata`yr'' "
}	


/********************************************************************************
I.D. Supplementing information to the VARHS household panel. 
1. Merge information from above to household panel dataset.
2. Label variables.  
********************************************************************************/

*===============================================================================*
* 4.  Supplementing information to the VARHS household panel. 					 *
*===============================================================================*

use "${RAWDATA}VARHS0816_household.dta", clear

*4a) Add plot data and other information to main panel dataset 
forvalues yr = 2008(2)2016 {
	merge 1:1 tinh_* quan_* xa_* ma_h0_* year using `plotdata`yr'', update
	*drop if _merge==2 //none so far
	drop _merge
}

*save "${INTDATA}VARHS0816_modified.dta", replace 
*use  "${INTDATA}VARHS0816_modified.dta", clear 

*4b) Drop households who do NOT OWN ANY AGRICULTURAL land.
drop if nrplot_ann_own==0 & nrplot_per_own==0 

*4c) Other variables and variable labels 
gen after2014 = (year>14)
gen polcon_any = (polcon_hhmem==1 | polcon_relat==1 | polcon_frien==1)
gen l_plotArea_agr_own = log(plotArea_agr_own)
gen l_plotArea_resid_own = log(plotArea_resid_own)
gen l_plotArea_agr_borr = log(plotArea_agr_borr)
gen l_plotArea_rent_sold = log(plotArea_agr_rent)

*Measure of exposure to Land Law 2013
label var sh_ann_nrpl "Number of Annual Plots Owned"
label var sh_ann_area "Area of Annual Plots Owned" // preferred

*Measure of investments based on number of plots 
label var sh_investSoiWa_nrpl "Plots with Soil and Water Investments"
label var sh_investInfra_nrpl "Plots with Infrastructure Investments"
label var sh_investTrees_nrpl "Plots with Tree Planting Investments"
label var sh_investAquac_nrpl "Plots with Aquaculture Investments"
label var sh_investAny_nrpl "Plots with Any Investments"

*Measure of investments based on area of plots // preferred 	
label var sh_investSoiWa_area "Plots with Soil and Water Investments"
label var sh_investInfra_area "Plots with Infrastructure Investments"
label var sh_investTrees_area "Plots with Tree Planting Investments"
label var sh_investAquac_area "Plots with Aquaculture Investments"
label var sh_investAny_area "Plots with Any Investments"

*Whether Land Law 	
label var landlaw_heard "Heard of Land Law (1=Yes)"
label var landlaw_knowl "Knowledge of Land Law"
label var landlaw_dura "Knowledge of Duration of Land Use Rights"

*Politically connected
label var polcon_any "Politically Connected (1=Yes)"

*4d) Save 
save "${FINALDATA}/Cleaned_hhdata.dta", replace



