*********************************************************************************
* "Tenurial security and agricultural investment: Evidence from Vietnam"		*
* Marc Bellemare, Kenn Chua, Julieth Santamaria, Khoa Vu						*
* Replication Files	- 2_Cleaning_plotpanel.do									*	
*********************************************************************************

*===============================================================================*
* 1. Plot data additional cleaning 												*
*===============================================================================*
	
	* Append plot-level datasets
		use "${INTDATA}Temp/temp_2008_2ABCDE.dta" , clear
		forval i=2010(2)2016 {
			append using "${INTDATA}Temp/temp_`i'_2ABCDE.dta"
		}
		
		order 	tinh_* quan_* xa_* ma_h0_* year
		
		foreach x in tinh quan xa ma_h0 {
			forval i=2008(2)2016 {
				forval j=2008(2)2016 {
					replace `x'_`i'=`x'_`j' if missing(`x'_`i') & `x'_`j'!=.
				}
			}
		}
		*rename 	*_2016 *
		g tinh = tinh_2016
		g quan = quan_2016
		g xa = xa_2016
		g ma_h0 = ma_h0_2016

		* drop 	*_2008 *_2010 *_2012 *_2014
		lab var year "Year"
		numlabel, add
		replace year = year + 2000
	
	// Type of crop
	
		gen 	annual_plot=1 if m2_q7==1, after(plotcode)
		replace annual_plot=0 if m2_q7==2
		drop if annual_plot==.
		lab def plot 1 "Annual" 0 "Perennial", replace
		lab val annual_plot plot
		lab var annual_plot "Annual or Perennial plot"
	
	
	// Investment variables
	
		gen 	Investment1=(m2e_q1==1), after(annual_plot)
		replace Investment1=. if missing(m2e_q1)
		lab var Investment1 "Irrigation or soil and water conservation improvements"
	
		gen 	Investment2=(m2e_q8==1), after(Investment1)
		replace Investment2=. if missing(m2e_q8)
		lab var Investment2 "Permanent and semi-permanent infrastructure"
	
		gen 	Investment3=(m2e_q11==1), after(Investment2)
		replace Investment3=. if missing(m2e_q11)
		lab var Investment3 "Planting perennial trees"
	
		gen 	Investment4=(m2e_q5==1), after(Investment3)
		replace Investment4=. if missing(m2e_q5)
		lab var Investment4 "Aquaculture"
	
	
	// 	After dummy, time dummies and interactions
		/* In the survey of 2016 they asked about investments since July 2014,
		so we will only have one year after the treatment*/
		
		gen 	after=(year==2016), after(annual_plot)
		lab var after "1 after year 2013"
	
		forval i=2008(2)2016 {
			gen 	year_`i'=(year==`i')
			lab var year_`i' "Year `i'"
			gen 	int_annual_`i'=annual_plot*year_`i'
			lab var int_annual_`i' "Annual x `i'"
		}
		
		order year_* int_annual_*, after(annual_plot)
				
		gen 	int_annual_after=annual_plot*after, after(after)
		lab var int_annual_after "Annual x After"
	
		
	
	// Household ID
	
		egen 	hhid=group(tinh quan xa ma_h0)
		egen 	plotid=group(hhid plotcode)
		order 	hhid plotid, after( year)
		lab var hhid "HHID"
		lab var plotid "PlotID"
	
	// Restrictions
		
		gen 	restricted=1 if m2_q19_a ==1
		replace restricted=0 if m2_q19_a ==2
		lab var restricted "Formal restrictions on hh choice of crops"
		lab def yesno 1 "Yes" 0 "No", replace
		lab val restricted yesno
		
	// Ownership type
		
		lab def owns 1 "Owned" 2 "Borrowed" 3 "Rented out" 4 "Sold or taken away", replace
		lab val plotOwnship owns
	
	// Identify Switchers
	
		preserve
			keep annual_plot hhid year plotid
			reshape wide annual_plot, i(hhid plotid) j(year)
			egen years_observed=rownonmiss(annual_plot*)
			egen years_annual=rowtotal(annual_plot*)
			gen 	switchers=0 if years_observed==years_annual
			replace switchers=0 if years_annual==0
			replace switchers=1 if missing(switcher)
			lab def swit 1 "Switcher" 0 "Non-switcher"
			lab val switchers swit
			lab var switchers "Switchers"
			keep hhid plotid switchers
			tempfile switcher
			save `switcher'
		restore
		
		merge m:1 plotid hhid using `switcher'
		drop _merge
	
	// Year of land acquisition	
	
		gen 	Land_acquired_year=m2_q5
		replace Land_acquired_year=. if m2_q5==99
		replace Land_acquired_year=1993 if Land_acquired_year<=1993 & Land_acquired_year!=.
		lab var Land_acquired_year "Year land was acquired"
save "${INTDATA}TEMP_plotdata.dta", replace



use "${FINALDATA}Cleaned_hhdata.dta", clear
replace year = year + 2000
forvalues y = 2008(2)2016 {
	preserve
	keep if year == `y'
	count
	tempfile hhdata`y'
	save `hhdata`y''
	restore
}

foreach k in 08 10 12 14 16 {
	if "`k'" == "08" loc y = 2008
	if "`k'" == "10" loc y = 2010
	if "`k'" == "12" loc y = 2012
	if "`k'" == "14" loc y = 2014
	if "`k'" == "16" loc y = 2016
	use "${RAWDATA}Commune_clean/commune_`k'_clean.dta", clear
	
	foreach x in tinh quan xa {
		forval i=2008(2)2016 {
			forval j=2008(2)2016 {
				replace `x'_`i'=`x'_`j' if missing(`x'_`i') & `x'_`j'!=.
			}
		}
	}
	
	loc t = `y' - 2
	g agriculture_project = 0
	g irrigation_project = 0
	
	g all_agriculture_project = 0
	g all_irrigation_project = 0
	
	if `y' >= 2012 loc listn 1 2 3 4 5 6 7 8
	if `y' < 2012  loc listn 01 02 03 04 05 06 07 08 09 10
	foreach i of local listn {
		foreach x in a b c d {
			replace agriculture_project = agriculture_project + 1 if s3q1`x'_`i' == 1 & s3q2_`i' >= `t'
			replace irrigation_project = irrigation_project + 1 if s3q1`x'_`i' == 2 & s3q2_`i' >= `t'	
			
			replace all_agriculture_project = agriculture_project + 1 if s3q1`x'_`i' == 1
			replace all_irrigation_project = irrigation_project + 1 if s3q1`x'_`i' == 2
		}
	}
	
	if `y' < 2014 g percent_annual_land = s4q21_1/(s4q21_1 + s4q21_4)
	if `y' >= 2014 g percent_annual_land = s4q28_1/(s4q28_1 + s4q28_4)
	
	g irrigation_fee_waiver_commune = (s8q14 == 1) if ~missing(s8q14)
	
	tempfile cmdata`y'
	save `cmdata`y''
	
}

use "${INTDATA}TEMP_plotdata.dta", clear
local identifier ///
	tinh_2008 tinh_2010 tinh_2012 tinh_2014 tinh_2016 ///
	quan_2008 quan_2010 quan_2012 quan_2014 quan_2016 ///
	xa_2008 xa_2010 xa_2012 xa_2014 xa_2016 ///
	ma_h0_2008 ma_h0_2010 ma_h0_2012 ma_h0_2014 ma_h0_2016 ///
	year tinh quan xa ma_h0 plotid
keep `identifier'

forvalues y = 2008(2)2016 {
	preserve
	loc k = `y' - 2000
	keep if year == `y'
	// This is merging with the household-level data. Add household variables 
	merge m:1 tinh_`y' quan_`y' xa_`y' ma_h0_`y' year using `hhdata`y'', keepusing(natshock econshock qincome s3d_6 s5g_10 valdur hhincome pest)
	tab year if _merge == 1
	drop if _merge == 2
	drop _merge
	
	merge m:1 tinh_`y' quan_`y' xa_`y' using `cmdata`y'', keepusing(agriculture_project irrigation_project all_agriculture_project all_irrigation_project percent_annual_land irrigation_fee_waiver_commune)
	drop if _merge == 2
	drop _merge
	save "${INTDATA}plothh_`y'.dta", replace
	restore
}

use "${INTDATA}plothh_2008.dta", clear

forvalues y = 2010(2)2016 {
	append using "${INTDATA}plothh_`y'.dta"
}

g irrigation_fee_waiver = (s3d_6 == 1) if ~missing(s3d_6)
merge 1:1  tinh quan xa ma_h0 plotid year using "${INTDATA}TEMP_plotdata.dta"
assert _merge == 3
drop _merge
egen provID = group(tinh)

foreach v of varlist irrigation_project agriculture_project {
	replace `v' = 1 if `v' > 0 & ~missing(`v')
}
save "${FINALDATA}Cleaned_plotdata.dta", replace
