*********************************************************************************
* "Tenurial security and agricultural investment: Evidence from Vietnam"		*
* Marc Bellemare, Kenn Chua, Julieth Santamaria, Khoa Vu						*
* Replication Files	- 3_Results_descriptives.do									*	
*********************************************************************************
	
	/*
	glo 	PCUSER			""			// Change this one
	glo 	PATH 			"${PCUSER}VNLand_Replication/"   
	glo 	date_stamp 		`c(current_date)'
	 
	glo 	RAWDATA			"${PATH}Data/Raw/VARHS0816_v1/"
	glo 	INTDATA			"${PATH}Data/Processed/"
	glo 	FINALDATA 		"${PATH}Data/Final/"
	glo 	RESULTS 		"${PATH}Results/"
	glo 	GRAPHS			"${PATH}Graphs/"
	glo 	DOFILES			"${PATH}Code/"
	*/
	
	global star3 0.01
	global star2 0.05
	global star1 0.1
	
	use "${FINALDATA}Cleaned_plotdata.dta", clear
	
	
	** Additional cleaning
		replace m2_q17_b=. if m2_q17_b==99
		replace m2_q17_b=0 if m2_q17_b==2
		g plotValue_per_meter = m2_q6/m2_q3_a
		replace m2_q6 = m2_q6/100000
		
		ta plotOwnship, gen(Own_)
		
		* Red book
		
		replace m2_q2_a=. if m2_q2_a==99 // Do you have a red book for this land?
		rename m2_q2_a RedBook
		recode RedBook (2=0) 
		
	** Labels
	
		lab var m2_q3_a "Area plot (m2)"
		lab var m2_q1 "Distance from home to plot (m)"
		lab var restricted "Plot has crop restriction (1/0)"
		lab var switcher "Crop switching (1/0)"
		lab var m2_q17_b "Can construct permanent structures (1/0)"
		lab var Own_1 "\hspace{0.1cm} Owned"
		lab var Own_2 "\hspace{0.1cm} Borrowed"
		lab var Own_3 "\hspace{0.1cm} Rented out"
		lab var Own_4 "\hspace{0.1cm} Sold or taken away"
		lab var m2_q6 "Plot value (100 thousand VND)"
		lab var RedBook "Plot has red book (1/0)"
		lab var Investment1 "\hspace{0.1cm} Irrigation"
		lab var Investment2 "\hspace{0.1cm} Infrastructure"
		lab var Investment3 "\hspace{0.1cm} Tree planting"
		lab var Investment4 "\hspace{0.1cm} Aquaculture"
		lab var plotValue_per_meter "Plot value (1000 VND/m2)"
		
		drop if Own_4 == 1
		
		
*===============================================================================*
* Descriptive statistics - Table 1  											*
*===============================================================================*
	
		texdoc init "${RESULTS}Descriptives Table ${date_stamp}.tex", replace
		loc title "Plot-level descriptive statistics of the VAHRS sample"

		count if ~after & ~annual_plot
		loc PB = `r(N)'
		count if ~after & annual_plot
		loc AB = `r(N)'
		count if after & ~annual_plot
		loc PA = `r(N)'
		count if after & annual_plot
		loc AA = `r(N)'
		
		tex
		tex \begin{table}[h]
		tex \centering
		tex \caption{`title'}
		tex \begin{tabular}{lcccc}
		tex \hline \hline
		tex & \multicolumn{2}{c}{Before} & \multicolumn{2}{c}{After} \\
		tex \cmidrule(lr){2-3} \cmidrule(lr){4-5}
		tex & Perennial & Annual & Perennial & Annual \\
		tex & (N = `PB') & (N = `AB') & (N = `PA') & (N = `AA') \\
		tex \midrule
		tex & & & & \\

	loc set1 m2_q3_a plotValue_per_meter m2_q1 m2_q17_b restricted switchers  Investment1 Investment2 ///
			Investment3 Investment4 Own_1 Own_2 Own_3 RedBook   // These are the variables included in descriptives
	
		loc row = 0
		
		foreach x in `set1' {
			local label: var lab `x'
			forvalues i = 0/1 {
				forvalues j = 0/1 {
					sum `x' if after == `i' & annual_plot == `j'
					loc ind`i'_`j': di %4.2f `r(mean)'
					loc sd`i'_`j': di %4.2f `r(sd)'					
				}
			}
			
			if "`x'" == "Investment1" {
				tex Investment type (1/0) & & & \\
			}
			
			if "`x'" == "Own_1" {
				tex Type of ownership (1/0) & & & \\
			}
			
			tex `label' & `ind0_0' & `ind0_1' & `ind1_0' & `ind1_1' \\
			tex & (`sd0_0') & (`sd0_1') & (`sd1_0') & (`sd1_1') \\
		}
		tex \hline \hline
		tex \end{tabular}
		tex \end{table}
		
		
*===============================================================================*
* Descriptive statistics - Table 3  											*
*===============================================================================*		

		texdoc init "${RESULTS}DD Descriptives Table ${date_stamp}.tex", replace
		loc title "Differences in investment decisions for annual and perennial crop plots for pre- and post-2014"
		
		tex
		tex \begin{table}[h]
		tex \centering
		tex \caption{`title'}
		tex \begin{tabular}{lccccccc}
		tex \hline \hline
		tex & \multicolumn{3}{c}{Before} & \multicolumn{3}{c}{After} & Difference \\
		tex \cmidrule(lr){2-4} \cmidrule(lr){5-7}
		tex & Perennial & Annual & Difference & Perennial & Annual & Difference & in differences \\
		tex \midrule
		tex & & & & & & & \\
		
		forvalues i = 1/4 {
			if `i' == 1 local text "Irrigation"
			if `i' == 2 local text "Infrastructure"
			if `i' == 3 local text "Tree planting"
			if `i' == 4 local text "Aquaculture"
			
			forval y=0/1 { 	// 0 Before 1 After
				* Means
				forval x=0/1 {     // 0 Control 1 Treatment
					sum Investment`i' if (~restricted & plotOwn == 1) & annual_plot==`x' & after==`y'
					loc mean_`x'`y'_`i': 	di %4.2f `r(mean)'
					loc sd_`x'`y'_`i': 		di %4.2f `r(sd)'
				}
				* Differences over treatment
				ttest Investment`i' if (~restricted & plotOwn == 1) & after==`y', by(annual_plot)
					loc mean_d`y'_`i': 	di %4.2f  `mean_0`y'_`i''- `mean_1`y'_`i''
					loc sd_d`y'_`i': 	di %4.2f `r(se)'
			}
				* Diff in diff
				reg Investment`i' after annual_plot int_annual_after if (~restricted & plotOwn == 1)
					loc mean_did`i': 	di %4.2f _b[int_annual_after]
					loc se_did`i': 		di %4.2f _se[int_annual_after]
			
			
			tex  `text' & `mean_00_`i'' & `mean_10_`i'' & `mean_d0_`i'' & `mean_01_`i'' & `mean_11_`i'' & `mean_d1_`i'' & `mean_did`i'' \\
			tex 		& (`sd_00_`i'') & (`sd_10_`i'') & (`sd_d0_`i'') & (`sd_01_`i'') & (`sd_11_`i'') & (`sd_d1_`i'') & (`se_did`i'') \\
		}
		
	count if ~after & ~annual_plot & (~restricted & plotOwn == 1)
	loc B14 = `r(N)'
	count if ~after & annual_plot & (~restricted & plotOwn == 1)
	loc C14 = `r(N)'
	count if after & ~annual_plot & (~restricted & plotOwn == 1)
	loc F14 = `r(N)'
	count if after & annual_plot & (~restricted & plotOwn == 1)
	loc G14 = `r(N)'
	
	tex \midrule
	tex Observations & `B14' & `C14' & & `F14' & `G14' & \\
	tex \hline \hline
	tex \end{tabular}
	tex \end{table}

	texdoc c
