*********************************************************************************
* "Tenurial security and agricultural investment: Evidence from Vietnam"		*
* Marc Bellemare, Kenn Chua, Julieth Santamaria, Khoa Vu						*
* Replication Files	- 3_Results_regression.do									*	
*********************************************************************************
	
	/*
	glo 	PCUSER			"~/Desktop/"			// Change this one
	glo 	PATH 			"${PCUSER}VNFP_Clean/"   // Change this one 
	glo 	date_stamp 		`c(current_date)'
	 
	glo 	RAWDATA			"${PATH}Data/Raw/VARHS0816_v1/"
	glo 	INTDATA			"${PATH}Data/Processed/"
	glo 	FINALDATA 		"${PATH}Data/Final/"
	glo 	RESULTS 		"${PATH}Results/"
	glo 	GRAPHS			"${PATH}Graphs/"
	glo 	DOFILES			"${PATH}Code/"
	*/
	
	global star3 0.01
	global star2 0.05
	global star1 0.1
	
	
// Set up the locals

	loc note "Note: Clustered standard errors in parenthesis. Number of observations in bracket. Each cell corresponds to an individual OLS regression in which the outcome variable is specified in every row. Seven specifications are analyzed. Model 1 regress the corresponding outcome to a dummy of whether the plot is annual or perennial, a time dummy that takes the value of 1 in year 2016, and the interaction of the latter two dummies. Model 2 includes year fixed effects. Model 3 adds plot fixed effects. Model 4 adds province-year fixed effects. Model 5 adds a control for whether commune applied for Irrigation Fee Waiver. Model 6 adds a control for whether commune had any irrigation-related project in past 2 years. Model 7 adds a control for whether commune had any agriculture-related project in past 2 years. All specifications control for plot area.  *** p<0.01, ** p<0.05, * p<0.1"
	
	local condition1 "if ~restricted & plotOwn == 1"
	local condition2 "if ~switchers & ~restricted & plotOwn == 1"
	
	local control1 annual_plot after m2_q3_a
	local control2 annual_plot after m2_q3_a i.year
	local control3 annual_plot after m2_q3_a i.year
	local control4 annual_plot after m2_q3_a i.provID##i.year
	local control5 annual_plot after m2_q3_a irrigation_fee_waiver_commune i.provID##i.year
	local control6 annual_plot after m2_q3_a irrigation_fee_waiver_commune irrigation_project i.provID##i.year
	local control7 annual_plot after m2_q3_a irrigation_fee_waiver_commune irrigation_project agriculture_project i.provID##i.year

// Graph the trends first
	use "${FINALDATA}Cleaned_plotdata.dta", clear
	xtset plotid year
	
// Set up the tex file
	texdoc init "${RESULTS}Regression Tables ${date_stamp}.tex", replace
	
*===============================================================================*
* Main Results - Table 4			  											*
*===============================================================================*
	use "${FINALDATA}Cleaned_plotdata.dta", clear
	xtset plotid year
	keep if year <= 2014
	drop after int_annual_after
	g after = (year >= 2010)
	g int_annual_after = after * annual_plot
	
	local title1 "Placebo test using the pre-treatment period - owned, non-restricted plots"

forvalues table = 1/1 {
		
		tex
		tex % Placebo test
		tex \begin{table}[h]
		tex \scriptsize
		tex \centering
		tex \caption{`title`table''}
		tex \label{table:placebo}
		tex \begin{tabular}{lccccccc}
		tex \hline \hline
		tex	Outcomes & Model 1 &  Model 2 & Model 3 & Model 4 & Model 5 & Model 6 & Model 7  \\ \hline
		tex & & & & & & &   \\
		
		forvalues i = 1/4 {
		if `i' == 1 local text "Irrigation"
		if `i' == 2 local text "Infrastructure"
		if `i' == 3 local text "Tree-planting"
		if `i' == 4 local text "Aquaculture"

			forvalues  c = 1/7 {
				// The first two columns are regular OLS and the rest are plot FE models:
				if `c' <= 2 reg Investment`i' int_annual_after `control`c'' `condition`table'', cluster (hhid)
				if `c' > 2 xtreg Investment`i' int_annual_after `control`c'' `condition`table'', cluster (hhid) fe

				matrix result = r(table)
					local beta = result[1, 1]
					local se = result[2, 1]
					local p = result[4, 1]
					local obs = e(N)
					
					if `p' <= $star3 local star_`i'_`c' "***"
					if `p' > $star3 & `p' <= $star2 local star_`i'_`c' "**"
					if `p' > $star2 & `p' <= $star1 local star_`i'_`c' "*"
					if `p' > $star1 local star_`i'_`c' ""
					
					local cellbeta_`i'_`c': di %4.3f `beta'
					local cellse_`i'_`c': di %4.3f `se'
					local cellobs_`i'_`c': di %9.0f  `obs'
			}

			tex `text' & `cellbeta_`i'_1'`star_`i'_1' & `cellbeta_`i'_2'`star_`i'_2' & `cellbeta_`i'_3'`star_`i'_3' & `cellbeta_`i'_4'`star_`i'_4' & `cellbeta_`i'_5'`star_`i'_5' & `cellbeta_`i'_6'`star_`i'_6' & `cellbeta_`i'_7'`star_`i'_7' \\
			tex & (`cellse_`i'_1') & (`cellse_`i'_2') & (`cellse_`i'_3') & (`cellse_`i'_4') & (`cellse_`i'_5') & (`cellse_`i'_6') & (`cellse_`i'_7') \\
			tex & [`cellobs_`i'_1'] & [`cellobs_`i'_2'] & [`cellobs_`i'_3'] & [`cellobs_`i'_4'] & [`cellobs_`i'_5'] & [`cellobs_`i'_6'] & [`cellobs_`i'_7'] \\
			tex & & & & & & & \\
		}
		tex Year FE & No & Yes & Yes & No & No & No & No \\
		tex Plot FE & No & No & Yes & Yes & Yes & Yes & Yes \\
		tex Province-year FE & No & No & No & Yes & Yes & Yes & Yes \\
		tex Irrigation Fee Waiver & No & No & No & No & Yes & Yes & Yes \\
		tex New irrigation project & No & No & No & No & Yes & Yes & Yes \\
		tex New agriculture project & No & No & No & No & No & No & Yes \\
		tex \hline \hline
		tex \multicolumn{8}{p{0.9\textwidth}}{\tiny{`note'}} \\
		tex \end{tabular}
		tex \end{table}
}
	
*===============================================================================*
* Main Results - Table 5 and 6			  											*
*===============================================================================*
use "${FINALDATA}Cleaned_plotdata.dta", clear
xtset plotid year	
local title1 "Effects on Land Law on investment for owned, non-restricted plots"
local title2 "Effects on Land Law on investment for owned, non-restricted, non-switching plots"

forvalues table = 1/2 {
		
		tex % Main results:
		tex \begin{table}[h]
		tex \scriptsize
		tex \centering
		tex \caption{`title`table''}
		tex \label{table:main`table'}
		tex \begin{tabular}{lccccccc}
		tex \hline \hline
		tex	Outcomes & Model 1 &  Model 2 & Model 3 & Model 4 & Model 5 & Model 6 & Model 7  \\ \hline
		tex & & & & & & &   \\
		
		forvalues i = 1/4 {
		if `i' == 1 local text "Irrigation"
		if `i' == 2 local text "Infrastructure"
		if `i' == 3 local text "Tree-planting"
		if `i' == 4 local text "Aquaculture"

			forvalues  c = 1/7 {
				// The first two columns are regular OLS and the rest are plot FE models:
				if `c' <= 2 reg Investment`i' int_annual_after `control`c'' `condition`table'', cluster (hhid)
				if `c' > 2 xtreg Investment`i' int_annual_after `control`c'' `condition`table'', cluster (hhid) fe

				matrix result = r(table)
					local beta = result[1, 1]
					local se = result[2, 1]
					local p = result[4, 1]
					local obs = e(N)
					
					if `p' <= $star3 local star_`i'_`c' "***"
					if `p' > $star3 & `p' <= $star2 local star_`i'_`c' "**"
					if `p' > $star2 & `p' <= $star1 local star_`i'_`c' "*"
					if `p' > $star1 local star_`i'_`c' ""
					
					local cellbeta_`i'_`c': di %4.3f `beta'
					local cellse_`i'_`c': di %4.3f `se'
					local cellobs_`i'_`c': di %9.0f  `obs'
			}

			tex `text' & `cellbeta_`i'_1'`star_`i'_1' & `cellbeta_`i'_2'`star_`i'_2' & `cellbeta_`i'_3'`star_`i'_3' & `cellbeta_`i'_4'`star_`i'_4' & `cellbeta_`i'_5'`star_`i'_5' & `cellbeta_`i'_6'`star_`i'_6' & `cellbeta_`i'_7'`star_`i'_7' \\
			tex & (`cellse_`i'_1') & (`cellse_`i'_2') & (`cellse_`i'_3') & (`cellse_`i'_4') & (`cellse_`i'_5') & (`cellse_`i'_6') & (`cellse_`i'_7') \\
			tex & [`cellobs_`i'_1'] & [`cellobs_`i'_2'] & [`cellobs_`i'_3'] & [`cellobs_`i'_4'] & [`cellobs_`i'_5'] & [`cellobs_`i'_6'] & [`cellobs_`i'_7'] \\
			tex & & & & & & & \\
		}
		tex Year FE & No & Yes & Yes & No & No & No & No \\
		tex Plot FE & No & No & Yes & Yes & Yes & Yes & Yes \\
		tex Province-year FE & No & No & No & Yes & Yes & Yes & Yes \\
		tex Irrigation Fee Waiver & No & No & No & No & Yes & Yes & Yes \\
		tex New irrigation project & No & No & No & No & Yes & Yes & Yes \\
		tex New agriculture project & No & No & No & No & No & No & Yes \\
		tex \hline \hline
		tex \multicolumn{8}{p{0.9\textwidth}}{\tiny{`note'}} \\
		tex \end{tabular}
		tex \end{table}
}




*===============================================================================*
* Main Results - Table 7			  											*
*===============================================================================*
	use "${FINALDATA}Cleaned_plotdata.dta", clear
	xtset plotid year
	keep if year == 2008 | year == 2016
	
	local condition1 "if ~restricted & plotOwn == 1"
	local condition2 "if ~switchers & ~restricted & plotOwn == 1"
	
	local title1 "Long-term effects of Land Law on investment for owned, non-restricted plots"

forvalues table = 1/1 {
		
		tex % Long term results
		tex \begin{table}[h]
		tex \scriptsize
		tex \centering
		tex \caption{`title`table''}
		tex \label{table:long_term}
		tex \begin{tabular}{lccccccc}
		tex \hline \hline
		tex	Outcomes & Model 1 &  Model 2 & Model 3 & Model 4 & Model 5 & Model 6 & Model 7  \\ \hline
		tex & & & & & & &   \\
		
		forvalues i = 1/4 {
		if `i' == 1 local text "Irrigation"
		if `i' == 2 local text "Infrastructure"
		if `i' == 3 local text "Tree-planting"
		if `i' == 4 local text "Aquaculture"

			forvalues  c = 1/7 {
				// The first two columns are regular OLS and the rest are plot FE models:
				if `c' <= 2 reg Investment`i' int_annual_after `control`c'' `condition`table'', cluster (hhid)
				if `c' > 2 xtreg Investment`i' int_annual_after `control`c'' `condition`table'', cluster (hhid) fe

				matrix result = r(table)
					local beta = result[1, 1]
					local se = result[2, 1]
					local p = result[4, 1]
					local obs = e(N)
					
					if `p' <= $star3 local star_`i'_`c' "***"
					if `p' > $star3 & `p' <= $star2 local star_`i'_`c' "**"
					if `p' > $star2 & `p' <= $star1 local star_`i'_`c' "*"
					if `p' > $star1 local star_`i'_`c' ""
					
					local cellbeta_`i'_`c': di %4.3f `beta'
					local cellse_`i'_`c': di %4.3f `se'
					local cellobs_`i'_`c': di %9.0f  `obs'
			}

			tex `text' & `cellbeta_`i'_1'`star_`i'_1' & `cellbeta_`i'_2'`star_`i'_2' & `cellbeta_`i'_3'`star_`i'_3' & `cellbeta_`i'_4'`star_`i'_4' & `cellbeta_`i'_5'`star_`i'_5' & `cellbeta_`i'_6'`star_`i'_6' & `cellbeta_`i'_7'`star_`i'_7' \\
			tex & (`cellse_`i'_1') & (`cellse_`i'_2') & (`cellse_`i'_3') & (`cellse_`i'_4') & (`cellse_`i'_5') & (`cellse_`i'_6') & (`cellse_`i'_7') \\
			tex & [`cellobs_`i'_1'] & [`cellobs_`i'_2'] & [`cellobs_`i'_3'] & [`cellobs_`i'_4'] & [`cellobs_`i'_5'] & [`cellobs_`i'_6'] & [`cellobs_`i'_7'] \\
			tex & & & & & & & \\
		}
		tex Year FE & No & Yes & Yes & No & No & No & No \\
		tex Plot FE & No & No & Yes & Yes & Yes & Yes & Yes \\
		tex Province-year FE & No & No & No & Yes & Yes & Yes & Yes \\
		tex Irrigation Fee Waiver & No & No & No & No & Yes & Yes & Yes \\
		tex New irrigation project & No & No & No & No & Yes & Yes & Yes \\
		tex New agriculture project & No & No & No & No & No & No & Yes \\
		tex \hline \hline
		tex \multicolumn{8}{p{0.9\textwidth}}{\tiny{`note'}} \\
		tex \end{tabular}
		tex \end{table}
}


