*********************************************************************************
* "Tenurial security and agricultural investment: Evidence from Vietnam"		*
* Marc Bellemare, Kenn Chua, Julieth Santamaria, Khoa Vu						*
* Replication Files	- 5_Results_appendix.do										*	
*********************************************************************************
	
	/*
	glo 	PCUSER			""			// Change this one
	glo 	PATH 			"${PCUSER}VNLand_Replication/"   
	glo 	date_stamp 		`c(current_date)'
	 
	glo 	RAWDATA			"${PATH}Data/Raw/VARHS0816_v1/"
	glo 	INTDATA			"${PATH}Data/Processed/"
	glo 	FINALDATA 		"${PATH}Data/Final/"
	glo 	RESULTS 		"${PATH}Results/"
	glo 	GRAPHS			"${PATH}Graphs/"
	glo 	DOFILES			"${PATH}Code/"
	*/
	
	global star3 0.01
	global star2 0.05
	global star1 0.1

*===============================================================================*
* Appendix Results - Table A1			  										*
*===============================================================================*

	loc note "Note: Clustered standard errors in parenthesis. Number of observations in bracket. Each cell corresponds to an individual OLS regression in which the outcome variable is specified in every row. Seven specifications with plot fixed effects are analyzed. Model 1 regress the corresponding outcome to a time dummy that takes the value of 1 in year 2016. Model 2 adds real household income in log. Model 3 replaces log household income with household income quintiles. Model 4 adds a control for total values of durable assets of household. Model 5 adds a control for whether household had any natural shock. Model 6 adds an indicator for whether household experienced any pest shock. Model 7 adds indicator for whether household experienced any economic shock. All specifications control for plot area.  *** p<0.01, ** p<0.05, * p<0.1"

	local control1 m2_q3_a
	local control2 m2_q3_a hhincome   
	local control3 m2_q3_a qincome   
	local control4 m2_q3_a hhincome valdur
	local control5 m2_q3_a hhincome valdur natshock
	local control6 m2_q3_a hhincome valdur natshock pest
	local control7 m2_q3_a hhincome valdur natshock pest econshock
// Graph the trends first
	use "${FINALDATA}Cleaned_plotdata.dta", clear
	xtset plotid year
	replace hhincome = ln(hhincome)
	replace  valdur = ln(  valdur)
forvalues table = 1/1 {
		
		texdoc init "${RESULTS}Regression Tables Appendix ${date_stamp}.tex", replace
		loc title "Changes in investment on annual crop plots after the 2013 Land Law."
		
		tex
		tex % Placebo test
		tex \begin{table}[h]
		tex \scriptsize
		tex \centering
		tex \caption{`title'}
		tex \label{table:placebo}
		tex \begin{tabular}{lccccccc}
		tex \hline \hline
		tex	Outcomes & Model 1 &  Model 2 & Model 3 & Model 4 & Model 5 & Model 6 & Model 7  \\ \hline
		tex & & & & & & &   \\
		
		forvalues i = 1/4 {
		if `i' == 1 local text "Irrigation"
		if `i' == 2 local text "Infrastructure"
		if `i' == 3 local text "Tree-planting"
		if `i' == 4 local text "Aquaculture"

			forvalues  c = 1/7 {
				// The first two columns are regular OLS and the rest are plot FE models:
				xtreg Investment`i' after `control`c'' if ~restricted & plotOwn == 1 & annual == 1, cluster (hhid) fe

				matrix result = r(table)
					local beta = result[1, 1]
					local se = result[2, 1]
					local p = result[4, 1]
					local obs = e(N)
					
					if `p' <= $star3 local star_`i'_`c' "***"
					if `p' > $star3 & `p' <= $star2 local star_`i'_`c' "**"
					if `p' > $star2 & `p' <= $star1 local star_`i'_`c' "*"
					if `p' > $star1 local star_`i'_`c' ""
					
					local cellbeta_`i'_`c': di %4.3f `beta'
					local cellse_`i'_`c': di %4.3f `se'
					local cellobs_`i'_`c': di %9.0f  `obs'
			}

			tex `text' & `cellbeta_`i'_1'`star_`i'_1' & `cellbeta_`i'_2'`star_`i'_2' & `cellbeta_`i'_3'`star_`i'_3' & `cellbeta_`i'_4'`star_`i'_4' & `cellbeta_`i'_5'`star_`i'_5' & `cellbeta_`i'_6'`star_`i'_6' & `cellbeta_`i'_7'`star_`i'_7' \\
			tex & (`cellse_`i'_1') & (`cellse_`i'_2') & (`cellse_`i'_3') & (`cellse_`i'_4') & (`cellse_`i'_5') & (`cellse_`i'_6') & (`cellse_`i'_7') \\
			tex & [`cellobs_`i'_1'] & [`cellobs_`i'_2'] & [`cellobs_`i'_3'] & [`cellobs_`i'_4'] & [`cellobs_`i'_5'] & [`cellobs_`i'_6'] & [`cellobs_`i'_7'] \\
			tex & & & & & & & \\
		}
		tex HH income (log) & No & Yes & Yes & No & No & No & No \\
		tex HH income (quintile) & No & No & Yes & No & Yes & Yes & Yes \\
		tex HH value of durable assets (log) & No & No & No & Yes & No & No & No \\
		tex HH experienced natural shock & No & No & No & No & Yes & Yes & Yes \\
		tex HH experienced pest shock & No & No & No & No & Yes & Yes & Yes \\
		tex HH experienced economic shock & No & No & No & No & No & No & Yes \\
		tex \hline \hline
		tex \multicolumn{8}{p{0.9\textwidth}}{\tiny{`note'}} \\
		tex \end{tabular}
		tex \end{table}
}
	
